@@ -32,11 +32,16 @@ list_resources <- function(dataset_name) {
   all_names <- purrr::map_chr(content$result$resources, ~ .x$name)
   all_date_created <- purrr::map_chr(content$result$resources, ~ .x$created) %>%
     as.POSIXct(format = "%FT%X", tz = "UTC")
-  all_date_modified <- purrr::map_chr(content$result$resources, ~ .x$last_modified) %>%
+  all_date_modified <- purrr::map_chr(
+    content$result$resources,
+    ~ .x$last_modified
+  ) %>%
     as.POSIXct(format = "%FT%X", tz = "UTC")
   return_value <- tibble::tibble(
-    "res_id" = all_ids, "name" = all_names,
-    "created" = all_date_created, "last_modified" = all_date_modified
+    "res_id" = all_ids,
+    "name" = all_names,
+    "created" = all_date_created,
+    "last_modified" = all_date_modified
   )
 
   return(return_value)
