@@ -10,8 +10,14 @@ test_that("returns data in the expected format", {
 })
 
 test_that("returns errors properly", {
-  expect_error(list_resources(), "argument \"dataset_name\" is missing, with no default$")
+  expect_error(
+    list_resources(),
+    "argument \"dataset_name\" is missing, with no default$"
+  )
   expect_error(list_resources("bad_name"), "dataset_name must be in dash-case")
   expect_error(list_resources("incorrect-name"), "Can't find the dataset name")
-  expect_error(list_resources("diagnostic-waiting-time"), "diagnostic-waiting-times")
+  expect_error(
+    list_resources("diagnostic-waiting-time"),
+    "diagnostic-waiting-times"
+  )
 })
